<?php

namespace App\Http\Controllers\Api;


use App\Models\Ad;
use App\Models\City;
use App\Models\Favourite;
use App\Models\Category;
use App\Models\Sub_category;
use App\Models\Message;
use App\Models\Rating;
use App\Models\Slider;
use Validator;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\User;
use App\Models\Setting;
use Carbon\Carbon;


class AdController extends Controller
{

    public function categories($lang)
    {

        $categories = Category::where('status', 'active')->get();

        $data = [];
        foreach ($categories as $category) {

            $arr['id'] = $category->id;
            if ($lang == 'ar') {
                $arr['title'] = $category->title['ar'];
                $arr['note'] = $category->note['ar'];
            } else {
                $arr['title'] = $category->title['en'];
                $arr['note'] = $category->note['en'];
            }

            if ($category->image) {
                $arr['image'] = asset('images/category/' . $category->image);
            } else {
                $arr['image'] = '';
            }
            $arr['sub_count'] = (string)Sub_category::where(['id' => $category->id, 'status' => 'active'])->count();

            $data[] = $arr;
        }
        return response()->json(['value' => true, 'data' => $data]);

    }

    public function sub_categories($id, $lang)
    {

        $sub_categories = Sub_category::where(['status' => 'active', 'category_id' => $id])->get();
        $data = [];
        foreach ($sub_categories as $sub_category) {

            $arr['id'] = $sub_category->id;
            if ($lang == 'ar') {
                $arr['title'] = $sub_category->title['ar'];
            } else {
                $arr['title'] = $sub_category->title['en'];
            }

            if ($sub_category->image) {
                $arr['image'] = asset('images/subcategory/' . $sub_category->image);
            } else {
                $arr['image'] = '';
            }
            $arr['ad_count'] = (string)Ad::where(['sub_category_id' => $sub_category->id, 'status' => 'active'])->count();

            $data[] = $arr;
        }
        return response()->json(['value' => true, 'data' => $data]);

    }


    public function all_ads($id, $lang)
    {

        $items = Ad::where('status', 'active')->latest()->get();

        $data = [];
        foreach ($items as $item) {

            $arr['id'] = $item->id;
            $arr['title'] = $item->title;
            $arr['price'] = $item->price;

            if ($lang == 'ar') {
                $arr['city'] = $item->Cities->name['ar'];
                $arr['Sub_category'] = $item->Sub_category->title['ar'];
            } else {
                $arr['city'] = $item->Cities->name['en'];
                $arr['Sub_category'] = $item->Sub_category->title['en'];
            }
            $arr['user_name'] = $item->Users ? $item->Users->name : '';
            $arr['admin_name'] = $item->Admins ? $item->Admins->name : '';
            $favorite_item = Favourite::where(['ad_id' => $item->id, 'user_id' => $id])->first();
            if ($favorite_item) {
                $arr['favorite_item'] = 'true';
            } else {
                $arr['favorite_item'] = 'false';
            }
            $rating = Rating::where('ad_id', $item->id)->sum('num_rate');
            $rating_count = Rating::where('ad_id', $item->id)->count('num_rate');
            if ($item->image) {
                $images = $item->image;
                $arr_image = [];
                foreach ($images as $image) {
                    $arr_image[] = asset('images/ad/' . $image);
                }
                $arr['images'] = $arr_image;
            } else {
                $arr['images'] = [];

            }
            if ($rating_count == 0):
                $arr['rating'] = "0";
            else:
                $arr['rating'] = (string)round($rating / $rating_count);

            endif;
            Carbon::setLocale($lang);
            $arr['since'] = Carbon::parse($item->created_at)->diffForHumans();

            $data[] = $arr;
        }
        return response()->json(['value' => true, 'data' => $data]);

    }


    public function ads_by_sub(Request $request, $lang)
    {

        if ($request->user_id && $request->sub_category_id) {


            $items = Ad::where(['status' => 'active', 'sub_category_id' => $request->sub_category_id])->latest()->get();

            $data = [];
            foreach ($items as $item) {

                $arr['id'] = $item->id;
                $arr['title'] = $item->title;
                $arr['price'] = $item->price;

                if ($lang == 'ar') {
                    $arr['city'] = $item->Cities->name['ar'];
                    $arr['Sub_category'] = $item->Sub_category->title['ar'];
                } else {
                    $arr['city'] = $item->Cities->name['en'];
                    $arr['Sub_category'] = $item->Sub_category->title['en'];
                }
                $arr['user_name'] = $item->Users ? $item->Users->name : '';
                $arr['admin_name'] = $item->Admins ? $item->Admins->name : '';
                $favorite_item = Favourite::where(['ad_id' => $item->id, 'user_id' => $request->user_id])->first();
                if ($favorite_item) {
                    $arr['favorite_item'] = 'true';
                } else {
                    $arr['favorite_item'] = 'false';
                }
                $rating = Rating::where('ad_id', $item->id)->sum('num_rate');
                $rating_count = Rating::where('ad_id', $item->id)->count('num_rate');
                $images = $item->image;

                if ($images) {

                    $arr_image = [];
                    foreach ($images as $image) {
                        $arr_image[] = asset('images/ad/' . $image);
                    }
                    $arr['images'] = $arr_image;
                } else {
                    $arr['images'] = [];
                }
                if ($rating_count == 0):
                    $arr['rating'] = "0";
                else:
                    $arr['rating'] = (string)round($rating / $rating_count);

                endif;
                Carbon::setLocale($lang);
                $arr['since'] = Carbon::parse($item->created_at)->diffForHumans();

                $data[] = $arr;
            }
            return response()->json(['value' => true, 'data' => $data]);
        }
        return response()->json(['value' => false]);

    }

    public function ad_item(Request $request, $lang)
    {

        if ($request->user_id && $request->ad_id) {

            $item = Ad::find($request->ad_id);
            $arr['id'] = $item->id;
            $arr['title'] = $item->title;
            $arr['price'] = $item->price;
            $arr['note'] = $item->note;
            $arr['lat'] = $item->lat;
            $arr['lng'] = $item->lng;
            if ($lang == 'ar') {
                $arr['city'] = $item->Cities->name['ar'];
                $arr['Sub_category'] = $item->Sub_category->title['ar'];
            } else {
                $arr['city'] = $item->Cities->name['en'];
                $arr['Sub_category'] = $item->Sub_category->title['en'];
            }
            $arr['user_name'] = $item->Users ? $item->Users->name : '';
            $arr['admin_name'] = $item->Admins ? $item->Admins->name : '';
            $favorite_item = Favourite::where(['ad_id' => $item->id, 'user_id' => $request->user_id])->first();
            if ($favorite_item) {
                $arr['favorite_item'] = 'true';
            } else {
                $arr['favorite_item'] = 'false';
            }
            $rating = Rating::where('ad_id', $item->id)->sum('num_rate');
            $rating_count = Rating::where('ad_id', $item->id)->count('num_rate');

            $images = $item->image;
            if ($images) {

                $arr_image = [];
                foreach ($images as $image) {
                    $arr_image[] = asset('images/ad/' . $image);
                }
                $arr['images'] = $arr_image;
            } else {
                $arr['images'] = [];
            }
            if ($rating_count == 0):
                $arr['rating'] = "0";
            else:
                $arr['rating'] = (string)round($rating / $rating_count);

            endif;
            Carbon::setLocale($lang);
            $arr['since'] = Carbon::parse($item->created_at)->diffForHumans();

            $ratings = Rating::where('ad_id', $item->id)->latest()->get();

            $data = [];
            foreach ($ratings as $rating) {

                $arr_rate['id'] = $rating->id;
                $arr_rate['note'] = $rating->note;
                $arr_rate['rating'] = $rating->num_rate;
                $arr_rate['user_name'] = $rating->Users->name;
                Carbon::setLocale($lang);
                $arr_rate['since'] = Carbon::parse($rating->created_at)->diffForHumans();
                Carbon::setLocale($lang);
                $arr['since'] = Carbon::parse($rating->created_at)->diffForHumans();
                $data[] = $arr_rate;
            }
            return response()->json(['value' => true, 'ad' => $arr, 'ratings' => $data]);
        }
        return response()->json(['value' => false]);

    }


    public function add_rating(Request $request, $lang)
    {
        if ($request->user_id && $request->ad_id) {

            $rating = new rating();

            $rating->ad_id = $request->ad_id;
            $rating->note = $request->note;
            $rating->num_rate = $request->num_rate;
            $rating->user_id = $request->user_id;

            $rating->save();


            $item = Ad::find($request->ad_id);
            $arr['id'] = $item->id;
            $arr['title'] = $item->title;
            $arr['price'] = $item->price;
            $arr['note'] = $item->note;
            $arr['lat'] = $item->lat;
            $arr['lng'] = $item->lng;
            if ($lang == 'ar') {
                $arr['city'] = $item->Cities->name['ar'];
                $arr['Sub_category'] = $item->Sub_category->title['ar'];
            } else {
                $arr['city'] = $item->Cities->name['en'];
                $arr['Sub_category'] = $item->Sub_category->title['en'];
            }
            $arr['user_name'] = $item->Users ? $item->Users->name : '';
            $arr['admin_name'] = $item->Admins ? $item->Admins->name : '';

            $favorite_item = Favourite::where(['ad_id' => $item->id, 'user_id' => $request->user_id])->first();
            if ($favorite_item) {
                $arr['favorite_item'] = 'true';
            } else {
                $arr['favorite_item'] = 'false';
            }
            $rating = Rating::where('ad_id', $item->id)->sum('num_rate');
            $rating_count = Rating::where('ad_id', $item->id)->count('num_rate');

            $images = $item->image;

            $arr_image = [];
            foreach ($images as $image) {
                $arr_image[] = asset('images/ad/' . $image);
            }
            $arr['images'] = $arr_image;

            if ($rating_count == 0):
                $arr['rating'] = "0";
            else:
                $arr['rating'] = (string)round($rating / $rating_count);

            endif;
            Carbon::setLocale($lang);
            $arr['since'] = Carbon::parse($item->created_at)->diffForHumans();

            $ratings = Rating::where('ad_id', $item->id)->latest()->get();

            $data = [];
            foreach ($ratings as $rating) {

                $arr_rate['id'] = $rating->id;
                $arr_rate['note'] = $rating->note;
                $arr_rate['rating'] = $rating->num_rate;
                $arr_rate['user_name'] = $rating->Users->name;
                Carbon::setLocale($lang);
                $arr_rate['since'] = Carbon::parse($rating->created_at)->diffForHumans();
                $data[] = $arr_rate;
            }
            return response()->json(['value' => true, 'ad' => $arr, 'ratings' => $data]);
        }

        return response()->json(['value' => false]);

    }

    public function search(Request $request, $lang)
    {

        if ($request->title && $request->category_id && $request->user_id && $request->from && $request->to && $request->city_id) {
            $from = (integer)$request->input('from');
            $to = (integer)$request->input('to');
            $category = Category::find($request->category_id);
            $sub_ids = $category->Sub_category->pluck('id');
            $items = Ad::whereBetween('price', [$from, $to])->whereIn('sub_category_id', $sub_ids)->where('title', 'like', '%' . $request->title . '%')->where(['city_id' => $request->city_id])->get();

            $data = [];
            foreach ($items as $item) {

                $arr['id'] = $item->id;
                $arr['title'] = $item->title;
                $arr['price'] = $item->price;
                if ($lang == 'ar') {
                    $arr['city'] = $item->Cities->name['ar'];
                    $arr['Sub_category'] = $item->Sub_category->title['ar'];
                } else {
                    $arr['city'] = $item->Cities->name['en'];
                    $arr['Sub_category'] = $item->Sub_category->title['en'];
                }
                $arr['user_name'] = $item->Users ? $item->Users->name : '';
                $arr['admin_name'] = $item->Admins ? $item->Admins->name : '';
                $favorite_item = Favourite::where(['ad_id' => $item->id, 'user_id' => $request->user_id])->first();
                if ($favorite_item) {
                    $arr['favorite_item'] = 'true';
                } else {
                    $arr['favorite_item'] = 'false';
                }
                $rating = Rating::where('ad_id', $item->id)->sum('num_rate');
                $rating_count = Rating::where('ad_id', $item->id)->count('num_rate');

                $images = $item->image;
                if ($images) {
                    $arr_image = [];
                    foreach ($images as $image) {
                        $arr_image[] = asset('images/ad/' . $image);
                    }
                    $arr['images'] = $arr_image;
                } else {
                    $arr['images'] = [];

                }

                if ($rating_count == 0):
                    $arr['rating'] = "0";
                else:
                    $arr['rating'] = (string)round($rating / $rating_count);

                endif;
                Carbon::setLocale($lang);
                $arr['since'] = Carbon::parse($item->created_at)->diffForHumans();

                $data[] = $arr;
            }
            return response()->json(['value' => true, 'data' => $data]);
        }
        return response()->json(['value' => false]);

    }


    public function favourites(Request $request, $lang)
    {

        $user = User::find($request->user_id);
        $ad = Ad::find($request->ad_id);

        if ($user && $ad) {

            $favourite = Favourite::where(['user_id' => $request->user_id, 'ad_id' => $request->ad_id])->first();

            if ($favourite) {

                $favourite->delete();

                $lang == 'ar' ? $msg = 'تم الحذف من المفضلة' : $msg = 'Deleted from Favorites';
                return response()->json([
                    'value' => false,
                    'msg' => $msg
                ]);

            } else {
                $new_favourite = new Favourite();
                $new_favourite->user_id = $request->user_id;
                $new_favourite->ad_id = $request->ad_id;
                $new_favourite->save();

                $lang == 'ar' ? $msg = 'تم الاضافة الى المفضلة' : $msg = 'Added to Favorites';
                return response()->json([
                    'value' => true,
                    'msg' => $msg
                ]);
            }
        } else {
            return response()->json(['value' => false]);

        }


    }

    public function add_ad(Request $request, $lang)
    {

        $ad = new Ad();

        $ad->title = $request->title;
        $ad->note = $request->note;
        $ad->price = $request->price;
        $ad->sub_category_id = $request->sub_category_id;
        $ad->city_id = $request->city_id;
        $ad->user_id = $request->user_id;
        $ad->lat = $request->lat;
        $ad->lng = $request->lng;
        $ad->save();

        if ($request['image']) {
            foreach ($request['image'] as $image) {
                $image_name = md5($image->getClientOriginalName()) . '.' . $image->getClientOriginalExtension();
                $image->move(public_path('images/ad'), $image_name);
                $ad->image = $image_name;
                $ad->update();
            }
        }


        $arr['id'] = $ad->id;
        $arr['title'] = $ad->title;
        $arr['price'] = $ad->price;
        $arr['note'] = $ad->note;
        $arr['lat'] = $ad->lat;
        $arr['lng'] = $ad->lng;
        $arr['user_name'] = $ad->Users->name;
        $arr['user_admin'] = '';
        if ($lang == 'ar') {
            $arr['city'] = $ad->Cities->name['ar'];
            $arr['Sub_category'] = $ad->Sub_category->title['ar'];
        } else {
            $arr['city'] = $ad->Cities->name['en'];
            $arr['Sub_category'] = $ad->Sub_category->title['en'];
        }
        $images = $ad->image;
        $arr_image = [];
        if ($images) {

            foreach ($images as $image) {
                $arr_image[] = asset('images/ad/' . $image);
            }
        }
        $arr['images'] = $arr_image;
        return response()->json(['value' => true, 'data' => $arr]);

    }

    public function cities($lang)
    {

        $cities = City::all();

        $data = [];
        foreach ($cities as $city) {

            $arr['id'] = $city->id;
            if ($lang == 'ar') {
                $arr['name'] = $city->name['ar'];
            } else {
                $arr['name'] = $city->name['en'];

            }
            $data[] = $arr;
        }
        return response()->json(['value' => true, 'data' => $data]);

    }

    public function favourites_items($id, $lang)
    {
        $fav_items = Favourite::where('user_id', $id)->get();

        $data = [];
        foreach ($fav_items as $fav_item) {

            $items = Ad::where('id', $fav_item->ad_id)->get();

            foreach ($items as $item) {
                $arr['id'] = $item->id;
                $arr['title'] = $item->title;
                $arr['price'] = $item->price;
                if ($lang == 'ar') {
                    $arr['city'] = $item->Cities->name['ar'];
                    $arr['Sub_category'] = $item->Sub_category->title['ar'];
                } else {
                    $arr['city'] = $item->Cities->name['en'];
                    $arr['Sub_category'] = $item->Sub_category->title['en'];
                }
                $arr['user_name'] = $item->Users ? $item->Users->name : '';
                $arr['admin_name'] = $item->Admins ? $item->Admins->name : '';

                $rating = Rating::where('ad_id', $item->id)->sum('num_rate');
                $rating_count = Rating::where('ad_id', $item->id)->count('num_rate');
                if ($item->image) {
                    $images = $item->image;
                    $arr_image = [];
                    foreach ($images as $image) {
                        $arr_image[] = asset('images/ad/' . $image);
                    }
                    $arr['images'] = $arr_image;
                } else {
                    $arr['images'] = [];

                }
                if ($rating_count == 0):
                    $arr['rating'] = "0";
                else:
                    $arr['rating'] = (string)round($rating / $rating_count);

                endif;
                Carbon::setLocale($lang);
                $arr['since'] = Carbon::parse($item->created_at)->diffForHumans();

                $data[] = $arr;
            }
        }
        return response()->json(['value' => true, 'data' => $data]);

    }


    public function complaints_proposals(Request $request)
    {

        $contact = new Message();

        $contact->title = $request->title;
        $contact->message = $request->message;
        $contact->type = 'complaint';
        $contact->user_id = $request->user_id;

        $contact->save();

        $arr['id'] = $contact->id;
        $arr['title'] = $contact->title;
        $arr['message'] = $contact->message;
        $arr['user_name'] = $contact->Users->name;

        return response()->json(['value' => true, 'data' => $arr]);
    }


    public function about_us($lang)
    {

        $about_us = Setting::value('about_us');


        if ($lang == 'ar') {
            $arr['about'] = $about_us['ar'];
        } else {
            $arr['about'] = $about_us['en'];
        }
        return response()->json(['value' => true, 'data' => $arr]);

    }

    public function sliders()
    {

        $sliders = Slider::all();

        $date = [];
        foreach ($sliders as $slider) {

            $arr['id'] = $slider->id;
            $arr['image'] = asset('images/slider/' . $slider->image);
            $arr['url'] = $slider->url;

            $date[] = $arr;

        }
        return response()->json(['value' => true, 'data' => $date]);

    }


}


